@@ -750,7 +750,7 @@ runjags.start <- function(model, monitor, data, inits, modules, factories, burni
 			swcat("Unable to call JAGS using '", jags, "' - try specifying the path to the JAGS binary as the jags argument, or using the rjags method.  Use the testjags() function for more detailed diagnostics.\n", sep="")
 			stop("Unable to call JAGS", call.=FALSE)
 		}
-		if(!jags.status$rjags.found && method%in%c("rjags","snow")){
+		if(method=="rjags" && !require(rjags)){
 			swcat("The rjags package was not found, either install the rjags package or use another method\n", sep="")
 			stop("The rjags package was not found", call.=FALSE)
 		}
